==> hook_event_dispatcher-3.0.0-rc1.tar.gz: hook_event_dispatcher/modules/views_event_dispatcher/tests/src/Kernel/ViewDataEventTest.php <==
<?php

namespace Drupal\Tests\views_event_dispatcher\Kernel;

use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\hook_event_dispatcher\Kernel\ListenerTrait;
use Drupal\views_event_dispatcher\Event\Views\ViewsDataAlterEvent;
use Drupal\views_event_dispatcher\Event\Views\ViewsDataEvent;

/**
 * Class ViewDataEventTest.
 *
 * @group hook_event_dispatcher
 * @group views_event_dispatcher
 */
class ViewDataEventTest extends KernelTestBase {

  use ListenerTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'action',
    'views',
    'hook_event_dispatcher',
    'views_event_dispatcher',
  ];

  /**
   * ViewsDataEvent test.
   *
   * @throws \Exception
   */
  public function testViewsDataEvent(): void {
    $this->listen(HookEventDispatcherInterface::VIEWS_DATA, 'onViewsData');
    $this->listen(HookEventDispatcherInterface::VIEWS_DATA_ALTER, 'onViewsDataAlter');

    $data = $this->container->get('views.views_data')->getAll();

    $this->assertArrayHasKey('test', $data);
    $this->assertEquals([
      0 => 'test_array_data',
      1 => 'other_test_array_data',
      'other_test' => ['some_data'],
    ], $data['test']);

    $this->assertArrayHasKey('some', $data);
    $this->assertEquals(['other_data'], $data['some']);
  }

  /**
   * Callback for ViewsDataEvent.
   *
   * @param \Drupal\views_event_dispatcher\Event\Views\ViewsDataEvent $event
   *   The event.
   */
  public function onViewsData(ViewsDataEvent $event) {
    $event->addData([
      'test' => [
        'test_array_data',
      ],
    ]);
    $event->addData([
      'test' => [
        'other_test_array_data',
      ],
    ]);
    $event->addData([
      'some' => [
        'other_data',
      ],
    ]);
  }

  /**
   * Callback for ViewsDataAlterEvent.
   *
   * @param \Drupal\views_event_dispatcher\Event\Views\ViewsDataAlterEvent $event
   *   The event.
   */
  public function onViewsDataAlter(ViewsDataAlterEvent $event) {
    $data = &$event->getData();
    $data['test']['other_test'] = ['some_data'];
  }

}

==> hook_event_dispatcher-4.0.0-rc1.tar.gz: hook_event_dispatcher/modules/views_event_dispatcher/tests/src/Kernel/ViewDataEventTest.php <==
<?php

namespace Drupal\Tests\views_event_dispatcher\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\hook_event_dispatcher\Kernel\ListenerTrait;
use Drupal\views_event_dispatcher\Event\Views\ViewsDataAlterEvent;
use Drupal\views_event_dispatcher\Event\Views\ViewsDataEvent;
use Drupal\views_event_dispatcher\ViewsHookEvents;

/**
 * Class ViewDataEventTest.
 *
 * @group hook_event_dispatcher
 * @group views_event_dispatcher
 */
class ViewDataEventTest extends KernelTestBase {

  use ListenerTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'action',
    'views',
    'hook_event_dispatcher',
    'views_event_dispatcher',
  ];

  /**
   * ViewsDataEvent test.
   *
   * @throws \Exception
   */
  public function testViewsDataEvent(): void {
    $this->listen(ViewsHookEvents::VIEWS_DATA, 'onViewsData');
    $this->listen(ViewsHookEvents::VIEWS_DATA_ALTER, 'onViewsDataAlter');

    $data = $this->container->get('views.views_data')->getAll();

    $this->assertArrayHasKey('test', $data);
    $this->assertEquals([
      0 => 'test_array_data',
      1 => 'other_test_array_data',
      'other_test' => ['some_data'],
    ], $data['test']);

    $this->assertArrayHasKey('some', $data);
    $this->assertEquals(['other_data'], $data['some']);
  }

  /**
   * Callback for ViewsDataEvent.
   *
   * @param \Drupal\views_event_dispatcher\Event\Views\ViewsDataEvent $event
   *   The event.
   */
  public function onViewsData(ViewsDataEvent $event): void {
    $event->addData([
      'test' => [
        'test_array_data',
      ],
    ]);
    $event->addData([
      'test' => [
        'other_test_array_data',
      ],
    ]);
    $event->addData([
      'some' => [
        'other_data',
      ],
    ]);
  }

  /**
   * Callback for ViewsDataAlterEvent.
   *
   * @param \Drupal\views_event_dispatcher\Event\Views\ViewsDataAlterEvent $event
   *   The event.
   */
  public function onViewsDataAlter(ViewsDataAlterEvent $event): void {
    $data = &$event->getData();
    $data['test']['other_test'] = ['some_data'];
  }

}
